package com.yunzhi.demo.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.demo.common.BaseController;
import com.yunzhi.demo.common.ResponseBean;
import com.yunzhi.demo.entity.SysBanner;
import com.yunzhi.demo.entity.TaPost;
import com.yunzhi.demo.entity.TaTopic;
import com.yunzhi.demo.service.ISysBannerService;
import com.yunzhi.demo.service.ITaPostService;
import com.yunzhi.demo.service.ITaTopicService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Api(tags = "小程序首页")
@RestController
@RequestMapping("/ma/index")
public class MaIndexController extends BaseController {

    @Autowired
    ISysBannerService iSysBannerService;

    @Autowired
    ITaTopicService iTaTopicService;

    @Autowired
    ITaPostService iTaPostService;

    @GetMapping("/banner")
    @ApiOperation(value="Banner列表", notes = "Banner列表", httpMethod = "GET", response = SysBanner.class)
    public ResponseBean getBannerList() throws Exception {
        List<SysBanner> bannerList = iSysBannerService.getIndexList();
        return ResponseBean.success(bannerList);
    }

    @GetMapping("/topic")
    @ApiOperation(value="热门列表", notes = "热门列表", httpMethod = "GET", response = TaTopic.class)
    public ResponseBean getTopicList() throws Exception {
        List<TaTopic> topicList = iTaTopicService.getIndexList();
        return ResponseBean.success(topicList);
    }

    @GetMapping("/post")
    @ApiOperation(value="最新文章", notes = "最新文章", httpMethod = "GET", response = TaPost.class)
    public ResponseBean getPostList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                    @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        IPage<TaPost> page = new Page<>(pageNum, pageSize);
        IPage<TaPost> postList = iTaPostService.getIndexList(page);
        return ResponseBean.success(postList);
    }
}
