package com.yunzhi.demo.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.demo.common.BaseController;
import com.yunzhi.demo.common.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.demo.service.ITaPointsLogService;
import com.yunzhi.demo.entity.TaPointsLog;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 积分历史 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-04-15
 */

@Api(tags = "积分历史")
@RestController
@RequestMapping("/")
public class TaPointsLogController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPointsLogController.class);

    @Autowired
    public ITaPointsLogService iTaPointsLogService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/points-log",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPointsLogList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                        @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                        @ApiParam("人员ID") @RequestParam(value ="personId") String personId) throws Exception{

		    IPage<TaPointsLog> pg = new Page<>(pageNum, pageSize);
            IPage<TaPointsLog> result = iTaPointsLogService.getPointsListBy(pg, personId);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taPointsLog 实体对象
     * @return
     */
    @RequestMapping(value="/taPointsLog",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taPointsLogAdd(@ApiParam("保存内容") @RequestBody TaPointsLog taPointsLog) throws Exception{

        if (iTaPointsLogService.save(taPointsLog)){
            return ResponseBean.success(taPointsLog);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taPointsLog/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taPointsLogDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iTaPointsLogService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taPointsLog 实体对象
     * @return
     */
    @RequestMapping(value="/taPointsLog/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taPointsLogUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                        @ApiParam("更新内容") @RequestBody TaPointsLog taPointsLog) throws Exception{

        if (iTaPointsLogService.updateById(taPointsLog)){
            return ResponseBean.success(iTaPointsLogService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taPointsLog/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPointsLogGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaPointsLogService.getById(id));
    }
}
