package com.yunzhi.demo.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.demo.common.BaseController;
import com.yunzhi.demo.common.Constants;
import com.yunzhi.demo.common.ResponseBean;
import com.yunzhi.demo.common.StringUtils;
import com.yunzhi.demo.entity.TdSchool;
import com.yunzhi.demo.service.ITdSchoolService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.demo.service.ITdHospitalService;
import com.yunzhi.demo.entity.TdHospital;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;

/**
 * <p>
    * 医务室 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-04-15
 */

@Api(tags = "医务室")
@RestController
@RequestMapping("/")
public class TdHospitalController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TdHospitalController.class);

    @Autowired
    ITdHospitalService iTdHospitalService;

    @Autowired
    ITdSchoolService iTdSchoolService;


    /**
     * 学校诊室管理
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/hospital",method= RequestMethod.GET)
    @ApiOperation(value="学校诊室管理", notes = "学校诊室管理", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean tdHospitalList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                       @ApiParam("所属学校") @RequestParam(value ="schoolId") String schoolId,
                                       @ApiParam("诊室名称") @RequestParam(value ="name", required = false) String name) throws Exception{

        TdSchool tdSchool = iTdSchoolService.getById(schoolId);
        if (null == tdSchool || Constants.STATUS_DELETED.equals(tdSchool.getStatus())) {
            throw new Exception("没有找到所属学校信息");
        }

        IPage<TdHospital> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TdHospital> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("school_id", schoolId);
        queryWrapper.gt("status", Constants.STATUS_DELETED);
        queryWrapper.like(!StringUtils.isEmpty(name),"name", "%"+name+"%");
        queryWrapper.orderByDesc("create_date");

        IPage<TdHospital> result = iTdHospitalService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存诊室信息
     * @param tdHospital 实体对象
     * @return
     */
    @RequestMapping(value="/admin/hospital",method= RequestMethod.POST)
    @ApiOperation(value="保存诊室信息", notes = "保存诊室信息", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean tdHospitalAdd(@ApiParam("诊室信息") @RequestBody TdHospital tdHospital) throws Exception{
        if (StringUtils.isEmpty(tdHospital.getSchoolId())) {
            throw new Exception("没有找到所属学校信息");
        }

        TdSchool tdSchool = iTdSchoolService.getById(tdHospital.getSchoolId());
        if (null == tdSchool || Constants.STATUS_DELETED.equals(tdSchool.getStatus())) {
            throw new Exception("没有找到所属学校信息");
        }

        if (StringUtils.isEmpty(tdHospital.getName())) {
            throw new Exception("没有填写诊室信息");
        }

        if (iTdHospitalService.save(tdHospital)){
            return ResponseBean.success(tdHospital);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 删除诊室
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/hospital/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除诊室", notes = "删除诊室", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean tdHospitalDelete(@ApiParam("诊室ID") @PathVariable String id) throws Exception{
        TdHospital tdHospital = iTdHospitalService.getById(id);
        if (null == tdHospital || Constants.STATUS_DELETED.equals(tdHospital.getStatus())) {
            return ResponseBean.success("success");
        }

        tdHospital.setStatus(Constants.STATUS_DELETED);

        if(iTdHospitalService.updateById(tdHospital)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改诊室信息
     * @param id  实体ID
     * @param tdHospital 实体对象
     * @return
     */
    @RequestMapping(value="/admin/hospital/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean tdHospitalUpdate(@ApiParam("对象ID") @PathVariable String id,
                                         @ApiParam("更新内容") @RequestBody TdHospital tdHospital) throws Exception{
        TdHospital origin = iTdHospitalService.getById(id);
        if (null == origin || Constants.STATUS_DELETED.equals(origin)) {
            throw new Exception("未找到更新记录");
        }

        if (StringUtils.isEmpty(tdHospital.getName())) {
            throw new Exception("没有填写诊室信息");
        }

        if (!id.equals(tdHospital.getHospitalId())) {
            throw new Exception("校验诊室信息出错");
        }

        // 允许修改的字段
        origin.setName(tdHospital.getName());
        origin.setStatus(tdHospital.getStatus());
        origin.setUpdateDate(LocalDateTime.now());

        if (iTdHospitalService.updateById(origin)){
            return ResponseBean.success(iTdHospitalService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }
}
