package com.yunzhi.demo.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.yunzhi.demo.common.Constants;
import com.yunzhi.demo.common.StringUtils;
import com.yunzhi.demo.entity.TaPerson;
import com.yunzhi.demo.mapper.TaPersonMapper;
import com.yunzhi.demo.service.ITaPersonService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yunzhi.demo.vo.StatisPerson;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * <p>
 * 人员 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-04-15
 */
@Service
public class TaPersonServiceImpl extends ServiceImpl<TaPersonMapper, TaPerson> implements ITaPersonService {

    @Autowired
    TaPersonMapper taPersonMapper;

    @Override
    public TaPerson getByOpenid(String openid) {
        QueryWrapper<TaPerson> queryWrapper = new QueryWrapper<TaPerson>()
                .eq("openid", openid)
                .gt("status", Constants.STATUS_DELETED);
        return getOne(queryWrapper);
    }

    @Override
    public int countStudent() {
        QueryWrapper<TaPerson> queryWrapper = new QueryWrapper<TaPerson>()
                .isNotNull("student_id")
                .gt("status", Constants.STATUS_DELETED);
        return count(queryWrapper);
    }

    @Override
    public IPage<StatisPerson> getStudentStatis(IPage<StatisPerson> pg, String name, String schoolId, String specialtyId, String asc, String desc) {
        if (StringUtils.isEmpty(asc) && StringUtils.isEmpty(desc)) {
            desc = "readedNum";
        }
        return taPersonMapper.getStudentStatis(pg, name, schoolId, specialtyId, getDBFieldBy(asc), getDBFieldBy(desc));
    }

    @Override
    public IPage<TaPerson> getStudentInfoPagedBy(IPage<TaPerson> pg, String name, String schoolId, String specialtyId, String phone, String studentId) {
        return taPersonMapper.getStudentInfoPagedBy(pg, name, schoolId, specialtyId, phone, studentId);
    }

    @Override
    public TaPerson getByPhone(String phone) {
        if (StringUtils.isEmpty(phone)) {
            return null;
        }
        QueryWrapper<TaPerson> queryWrapper = new QueryWrapper<TaPerson>()
                .eq("phone", phone)
                .gt("status", Constants.STATUS_DELETED);
        return getOne(queryWrapper);
    }

    private String getDBFieldBy(String name) {
        if (StringUtils.isEmpty(name)) {
            return null;
        }

        switch (name.toLowerCase()) {
            case "readedNum":
                return "readed_num";
            case "creditNum":
                return "credit_num";
            case "pointNum":
                return "point_num";
            default:
                return "saved_num";
        }
    }

    public TaPerson getByStudentId(String studentId) {
        QueryWrapper<TaPerson> queryWrapper = new QueryWrapper<TaPerson>()
                .eq("student_id", studentId)
                .gt("status", Constants.STATUS_DELETED);
        return getOne(queryWrapper);
    }
}
