package com.yunzhi.demo.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.yunzhi.demo.common.Constants;
import com.yunzhi.demo.entity.TaPerson;
import com.yunzhi.demo.entity.TaPersonData;
import com.yunzhi.demo.entity.TaPostData;
import com.yunzhi.demo.entity.TaReadLog;
import com.yunzhi.demo.mapper.TaPersonDataMapper;
import com.yunzhi.demo.mapper.TaPostDataMapper;
import com.yunzhi.demo.mapper.TaReadLogMapper;
import com.yunzhi.demo.service.ITaPostDataService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 文章统计 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-04-15
 */
@Service
public class TaPostDataServiceImpl extends ServiceImpl<TaPostDataMapper, TaPostData> implements ITaPostDataService {

    @Autowired
    TaPostDataMapper taPostDataMapper;

    @Autowired
    TaReadLogMapper taReadLogMapper;

    @Autowired
    TaPersonDataMapper taPersonDataMapper;

    @Async
    @Override
    public void recordBy(String postId, TaPerson taPerson) {
        // 先查询当前人员以前有没有阅读过
        List<TaReadLog> logList = taReadLogMapper.getReadBy(taPerson.getPersonId(), postId);
        boolean readed = null != logList && logList.size() > 0;

        int addPv = 1;
        int addUv = readed ? 0 : 1;

        // 更新人员的数据
        if (!readed) {
            taPersonDataMapper.increaseProp(taPerson.getPersonId(), "readed_num");
        }

        // 更新当前文章的数据
        taPostDataMapper.updatePvUvBy(postId, addUv, addPv);

        // 如果当前人员以前未读过
        if (!readed) {
            TaReadLog taReadLog = new TaReadLog();
            taReadLog.setPostId(postId);
            taReadLog.setPersonId(taPerson.getPersonId());
            taReadLog.setStatus(Constants.READ_READY);
            taReadLogMapper.insert(taReadLog);
        } else {
            TaReadLog taReadLog = logList.get(0);
            taReadLog.setUpdateDate(LocalDateTime.now());
            taReadLogMapper.updateById(taReadLog);
        }
    }

    @Override
    public Map<String, Object> getIndexBasicData() {
        return taPostDataMapper.getIndexBasicData();
    }

    @Override
    public int updateSaveData(String postId) {
        return taPostDataMapper.updatePostSaveData(postId);
    }

    @Override
    public int subSaveData(String postId) {
        return taPostDataMapper.subSaveData(postId);
    }
}
