package com.yunzhi.demo.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yunzhi.demo.common.Constants;
import com.yunzhi.demo.common.StringUtils;
import com.yunzhi.demo.entity.TaStudent;
import com.yunzhi.demo.mapper.TaStudentMapper;
import com.yunzhi.demo.service.ITaStudentService;
import com.yunzhi.demo.vo.ExportStatisPerson;
import com.yunzhi.demo.vo.StatisPerson;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 人员 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-04-15
 */
@Service
public class TaStudentServiceImpl extends ServiceImpl<TaStudentMapper, TaStudent> implements ITaStudentService {

    @Autowired
    TaStudentMapper taStudentMapper;

    @Override
    public int countStudent() {
        QueryWrapper<TaStudent> queryWrapper = new QueryWrapper<TaStudent>()
                .gt("status", Constants.STATUS_DELETED);
        return count(queryWrapper);
    }

    @Override
    public IPage<StatisPerson> getStudentStatis(IPage<StatisPerson> pg, String name, String schoolId, String specialtyId, String asc, String desc) {
        if (StringUtils.isEmpty(asc) && StringUtils.isEmpty(desc)) {
            desc = "readedNum";
        }
        return taStudentMapper.getStudentStatis(pg, name, schoolId, specialtyId, getDBFieldBy(asc), getDBFieldBy(desc));
    }

    @Override
    public IPage<TaStudent> getStudentInfoPagedBy(IPage<TaStudent> pg, String name, String schoolId, String specialtyId, String phone, String studentNo) {
        return taStudentMapper.getStudentInfoPagedBy(pg, name, schoolId, specialtyId, phone, studentNo);
    }

    @Override
    public TaStudent getByStudentNo(String schoolId, String studentNo) {
        QueryWrapper<TaStudent> queryWrapper = new QueryWrapper<TaStudent>()
                .eq("school_id", schoolId)
                .eq("student_no", studentNo)
                .gt("status", Constants.STATUS_DELETED);
        return getOne(queryWrapper);
    }

    @Override
    public TaStudent getByPersonId(String personId) {
        QueryWrapper<TaStudent> queryWrapper = new QueryWrapper<TaStudent>()
                .eq("person_id", personId)
                .gt("status", Constants.STATUS_DELETED);
        return getOne(queryWrapper);
    }

    @Override
    public TaStudent getByPhone(String phone) {
        QueryWrapper<TaStudent> queryWrapper = new QueryWrapper<TaStudent>()
                .eq("phone", phone)
                .gt("status", Constants.STATUS_DELETED);
        return getOne(queryWrapper);
    }

    @Override
    public List<ExportStatisPerson> exportStudentStatis(String name, String schoolId, String specialtyId) {
        return taStudentMapper.exportStudentStatis(name, schoolId, specialtyId);
    }

    private String getDBFieldBy(String name) {
        if (StringUtils.isEmpty(name)) {
            return null;
        }

        switch (name.toLowerCase()) {
            case "readedNum":
                return "readed_num";
            case "creditNum":
                return "credit_num";
            case "pointNum":
                return "point_num";
            default:
                return "saved_num";
        }
    }
}
